Configurations
==============

Pydantic models documentation for application configurations.

**Content**

* `Main`_
* `I/O`_
* `Solver`_

Main
----
.. automodule:: gnatss.configs.main
   :members:

I/O
----

.. automodule:: gnatss.configs.io
   :members:

Solver
------

.. automodule:: gnatss.configs.solver
   :members:
